@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CONFIGUREPLUGINDIALOG_H
-#define CONFIGUREPLUGINDIALOG_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QDialog>
@@ -45,4 +44,3 @@ private:
     QDialogButtonBox *mButtonBox = nullptr;
 };
 }
-#endif // CONFIGUREPLUGINDIALOG_H
