@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIGRATEFILEINFO_H
-#define MIGRATEFILEINFO_H
+#pragma once
 
 #include <QString>
 #include <QStringList>
@@ -48,4 +47,3 @@ private:
 };
 }
 
-#endif // MIGRATEFILEINFO_H
