@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILLIST_H
-#define BLACKLISTBALOOEMAILLIST_H
+#pragma once
 
 #include "pimcommonakonadi_private_export.h"
 #include <QHash>
@@ -56,4 +55,3 @@ private:
 };
 }
 
-#endif // BLACKLISTBALOOEMAILLIST_H
